"""
Copyright (c) 2019 Cypress Semiconductor Corporation

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
from cysecuretools.execute.programmer.pyocd_wrapper import Pyocd
from cysecuretools.execute.programmer.openocd_wrapper import Openocd

tools = {
    'pyocd': Pyocd,
    'openocd': Openocd
}


class ProgrammingTool:
    @staticmethod
    def create(name, path=None):
        """ Creates an instance of the on-chip debugger wrapper """
        tool_type = tools[name]
        tool = tool_type(name, path)
        return tool
